import React from "react";
import { DatePickerComponent } from '@syncfusion/ej2-react-calendars';
import { reportsService } from '../../../services';
import {
    Card,
    CardHeader,
    CardBody,
    CardFooter,
    CardTitle,
    FormGroup,
    Form,
    Row,
    Col
} from "reactstrap";
import LoadingOverlay from "react-loading-overlay";
import {ButtonComponent} from "@syncfusion/ej2-react-buttons";
import {
    ColumnDirective,
    ColumnsDirective,
    GridComponent,
    Inject,
    Sort,
    Toolbar,
    ExcelExport,
    Group
} from "@syncfusion/ej2-react-grids";

class NetNewChurnReport extends React.Component {
    constructor(props) {
        super(props);
        
        let fromDate = new Date();
        fromDate.setFullYear( fromDate.getFullYear() - 4 );
        fromDate.setMonth(0, 1)
        this.state = {
            fromDate: fromDate,
            toDate: new Date()
        };

        this.toolbarOptions = ['ExcelExport', 'Search'];
        this.groupOptions = { showGroupedColumn: false, columns: ['year','month'], ignoreCase: true, showDropArea: false };
        this.sortingOptions = {
            columns: [
                { field: 'year', direction: 'Descending' },
                { field: 'month', direction: 'Ascending' },
                { field: 'index', direction: 'Ascending' }
            ]
        };
        
        this.change = this.change.bind(this);
    }
    
    async componentDidMount() {
        document.getElementById('searchCriteriaDiv').addEventListener("keyup", (e) => {
            if (e.key === 'Enter') {
                this.submit(e);
            }
        });
    }
    change = (event, name) => {
        const { value } = event;
        this.setState({
            [name]: value
        });
    };
    async submit(e) {
        e.preventDefault();
        this.setState({ isLoading: true });
        const { fromDate, toDate } = this.state;
        const request = {
            fromDate: fromDate,
            toDate: toDate
        };

        const reportData = await reportsService.getNetNewChurnReportData(request);
        this.setState({ reportData: reportData });
        this.setState({ isLoading: false });
    };
    dataBound() {
        if (this.grid) {
            this.grid.groupModule.collapseAll();
        }
    }
    render() {
        const { reportData, isLoading } = this.state;
        return (
            <div className="content" id='searchCriteriaDiv'>
                <Row>
                    <Col md="6">
                        <Card>
                            <CardHeader>
                                <CardTitle tag="h4">Search Criteria</CardTitle>
                            </CardHeader>
                            <CardBody>
                                <Form>
                                    <Row>
                                        <Col className="pr-md-1" md="6">
                                            <div>
                                                <FormGroup>
                                                    <div style={{ display: 'flex', alignItems: 'center' }}>
                                                        <span className="e-label align-middle" style={{ float: 'left', marginRight: '10px' }}>From: </span>
                                                        <div style={{ overflow: "hidden", width: "150px" }}>
                                                            <DatePickerComponent id="datepicker" value={this.state.fromDate} placeholder="Enter date" style={{ overflow: 'hidden' }}
                                                                                 change={e => this.change(e, "fromDate")} />
                                                        </div>
                                                    </div>
                                                    <div style={{ display: 'flex', alignItems: 'center' }}>
                                                        <span className="e-label align-middle" style={{ float: 'left', marginRight: '28px' }}>To: </span>
                                                        <div style={{ overflow: "hidden", width: "150px" }}>
                                                            <DatePickerComponent id="datepicker" value={this.state.toDate} placeholder="Enter date" style={{ overflow: 'hidden' }}
                                                                                 change={e => this.change(e, "toDate")} />
                                                        </div>
                                                    </div>
                                                </FormGroup>
                                            </div>
                                        </Col>
                                    </Row>
                                </Form>
                            </CardBody>
                            <CardFooter className="text-left">
                                <ButtonComponent cssClass='e-info' onClick={this.submit.bind(this)} style={{ float: 'right' }}>Search</ButtonComponent>
                            </CardFooter>
                        </Card>
                    </Col>
                </Row>

                <LoadingOverlay
                    active={isLoading}
                    spinner
                    text='Loading.....'>
                    <Row className="mt-5">
                        <Col xs={12} md={12}>
                            <Card>
                                <CardHeader>
                                    <CardTitle tag="h4">Net New Churn</CardTitle>
                                </CardHeader>
                                <CardBody>
                                    <GridComponent id='grid' ref={g => this.grid = g} dataSource={reportData}
                                                   allowSorting={true} dataBound={this.dataBound.bind(this)}
                                                   allowExcelExport={true} sortSettings={this.sortingOptions}
                                                   allowGrouping={true} groupSettings={this.groupOptions}>
                                        <ColumnsDirective>
                                            <ColumnDirective field='year' headerText='Year' width='120' isPrimaryKey={true} enableGroupByFormat={true} clipMode='EllipsisWithTooltip'/>
                                            {/*<ColumnDirective field='monthDescription' headerText='Month' width='120' clipMode='EllipsisWithTooltip'/>*/}
                                            <ColumnDirective field='month' headerText='Month' width='120' enableGroupByFormat={true} clipMode='EllipsisWithTooltip'/>
                                            <ColumnDirective field='index' headerText='Index' width='120' clipMode='EllipsisWithTooltip' visible={false}/>
                                            <ColumnDirective field='type' headerText='Type' width='120' clipMode='EllipsisWithTooltip'/>
                                            <ColumnDirective field='count' headerText='Count' width='120' clipMode='EllipsisWithTooltip'/>
                                            <ColumnDirective field='dddc' headerText='DDDC' width='120' clipMode='EllipsisWithTooltip'/>
                                        </ColumnsDirective>
                                        <Inject services={[Sort, ExcelExport, Toolbar, Group]} />
                                    </GridComponent>
                                </CardBody>
                            </Card>
                        </Col>
                    </Row>
                </LoadingOverlay>
            </div>
        );
    }
}

export default NetNewChurnReport;
